@@ -1,8 +1,9 @@
 /* small helper to get the current subarch's loaddr */
 
 #include <stdio.h>
+#include <stdint.h>
 
-#include <subarch.h>
+#include "subarch.h"
 
 int main()
 {
