@@ -5,7 +5,7 @@
 #ifndef SUBARCH_H
 #define SUBARCH_H
 
-#include <types.h>
+#include <stdint.h>
 
 #define PAGE_SIZE	4096
 #define STACK_PAGES	16
@@ -23,18 +23,18 @@
  *  the loader.
  */
 struct kernel_load_block {
-	ULONG base;
-	ULONG reserved;
+	uint32_t base;
+	uint32_t reserved;
 };
 
 struct kernel_load_block kernel_load[] = {
 	{ /* IP22 */
-	.base =   0x88002000,
-	.reserved = 0x800000,
+	.base =     0x88002000,
+	.reserved =   0x800000,
 	},
 	{ /* IP32 */
 	.base     = 0x80004000,
-	.reserved = 0x800000,
+	.reserved =   0x800000,
 	},
 };
 
